==> xdvik-22.77.1.tar.gz: xdvik-22.77.1/texk/xdvik/search-dialog.h <==
/*
 * Copyright (c) 2003 Xdvik project team
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SEARCH_DIALOG_H
#define SEARCH_DIALOG_H

#include "xdvi-config.h"
#include "xdvi.h"

typedef enum { SEARCH_UP, SEARCH_DOWN } search_direction_t;

struct search_settings_t {
    char *term;
    Boolean use_regexp;
    Boolean match_case;
    search_direction_t direction;
    /* internal state management */
    Boolean from_toplevel; /* callback comes from toplevel window */
    Boolean new_search; /* whether search has been cancelled and should start anew */
    int x_pos, y_pos;	/* position of the search popup window */
    Boolean first_pass; /* first pass, or has search already wrapped? */
    int from_page;	/* page to start search from */
};

extern void dvi_search_dialog(void);

#endif /* SEARCH_DIALOG_H */

==> xdvik-22.77.2.tar.gz: xdvik-22.77.2/texk/xdvik/search-dialog.h <==
/*
 * Copyright (c) 2003 Xdvik project team
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
 * PAUL VOJTA OR ANY OTHER AUTHOR OF THIS SOFTWARE BE LIABLE FOR ANY CLAIM,
 * DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 * OTHER DEALINGS IN THE SOFTWARE.
 */

#ifndef SEARCH_DIALOG_H
#define SEARCH_DIALOG_H

#include "xdvi-config.h"
#include "xdvi.h"

typedef enum { SEARCH_UP = 0, SEARCH_DOWN, SEARCH_UNINITIALIZED } search_direction_t;

/* bounding box info for words. */
struct bbox_t {
    int ulx, uly, lrx, lry;
};

struct search_info_t {
    Boolean have_match;
    Boolean locked;	/* to block multiple searches */
    Boolean search_wrapped;	/* if restarting from start (or end) */
    int from_pos;
    int to_pos;
    int scan_page;
    int page_offset;	/* start of current scan */
};

struct search_settings_t {
    char *term;
    char *utf8_term;  /* term in UTF-8 encoding */
    char *posix_term; /* utf8_term with Perl abbreviations mapped to POSIX */
    Boolean use_regexp;
    Boolean case_sensitive;
    search_direction_t direction;
    struct search_info_t *searchinfo;
    /* internal state management */
    int x_pos, y_pos;	/* position of the search popup window */
    int from_page;	/* page to start search from */
    int curr_page;	/* current page of search search from */
    int to_page;	/* highest page already scanned */
};

extern void dvi_search_dialog(void);

#endif /* SEARCH_DIALOG_H */
